==> prestashop_1.4.1.0.zip: prestashop/modules/twenga/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'l\'API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_64ef67f03ba236aef261078101017d57'] = 'Rôle du module : export de vos produits sur Twenga et installation du suivi des ventes apportées par Twenga (inscription sur Twenga requise)';
$_MODULE['<{twenga}prestashop>twenga_2034864b8a4fce12f3621b7ec8912e95'] = 'Le module Twenga marche seulement dans certains pays (liste des iso codes :';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Désactiver';
$_MODULE['<{twenga}prestashop>twenga_526d688f37a86d3c3f27d0c5016eb71d'] = 'Réinitialiser';
$_MODULE['<{twenga}prestashop>twenga_a27dfe771799a09fd55fea73286eb6ab'] = 'Désinstaller';
$_MODULE['<{twenga}prestashop>twenga_f2a6c498fb90ee345d997f888fce3b18'] = 'Supprimer';
$_MODULE['<{twenga}prestashop>twenga_bf4510198726bc0736e7705e10fffd8b'] = 'Si vous êtes inscrit sur Twenga, l’activation de ce module est obligatoire.';
$_MODULE['<{twenga}prestashop>twenga_9d156e107098a77332f309c765b72b9c'] = 'En cas de dysfonctionnement, désinstallez ce module, installez la version la plus récente ici puis renseignez à nouveau votre hashkey et login Twenga.';
$_MODULE['<{twenga}prestashop>twenga_a9d7299384e1f3fc346790328ffa8ac3'] = 'Pour vous désinscrire ou toute autre question, contactez Twenga sur votre compte.';
$_MODULE['<{twenga}prestashop>twenga_fb3ecfb2800400fb01b0bfd39903e9fb'] = 'Version plus récente';
$_MODULE['<{twenga}prestashop>twenga_ea4788705e6873b424c65e91c2846b19'] = 'Annuler';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Les paramètres ne sont pas autorisés (voir détails) :';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Une erreur s\'est produite avec une méthode de l\'API Twenga (voir détails) :';
$_MODULE['<{twenga}prestashop>twenga_7edef656ee9e8861e734336a7adba650'] = 'Votre \"hashkey\" n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_3e6f1d35bdb6d0721c83c0a3f48ae345'] = 'Votre nom d\'utilisateur n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_19183e4de8ddfa3e032c112ba45fdc13'] = 'Votre mot de passe n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_802b207b05fe5cea22e11b9db804b33d'] = 'Votre authentification à échoué.';
$_MODULE['<{twenga}prestashop>twenga_6702ebde453c9145652c0b007489904c'] = 'Veuillez vérifier l\'email envoyé par Twenga après souscription. Si une erreur persiste, contactez le service de Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Une erreur est apparue en passant les paramètres à l\'API Twenga.';
$_MODULE['<{twenga}prestashop>twenga_94a3b708cddc22d83742fdbd0a8970d7'] = 'Votre pays par défaut est';
$_MODULE['<{twenga}prestashop>twenga_1f75825a8f4b083cbed0f95efc09abfd'] = 'Veuilez sélectionner un des pays disponibles approuvés par Twenga';
$_MODULE['<{twenga}prestashop>twenga_3ea33020a5535b0157de47e53e463633'] = 'Suivez ce lien pour changer le pays';
$_MODULE['<{twenga}prestashop>twenga_5d79ec5a879860ff8546580001fe80ee'] = 'Pour utiliser le webservice de Twenga, vous devez activer l\'extension \'curl\' de PHP';
$_MODULE['<{twenga}prestashop>twenga_5f77daeb6fc30c87e051e5b5d11b034c'] = 'Des erreurs sont apparues lors de l\'appel de la methode \"getSubscription\" avec L\'API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_da8ac71ff9563d9a5dd0f8894c8bc0ac'] = 'Référencez vos produits sur Twenga et suivez les ventes générées par Twenga';
$_MODULE['<{twenga}prestashop>twenga_0ed6e223384a822859461ca6bab72256'] = 'Vous êtes déjà inscrit à Twenga Ready to Sell ? ';
$_MODULE['<{twenga}prestashop>twenga_63f97ef2cb80a6cf0a8fa98453577601'] = 'Etape 1 : Récupérez votre clé Twenga dans l\'email envoyé par Twenga ou sur votre compte Twenga Ready to Sell (tools>tracking>hashkey). Cliquez aussi sur \"Tester le tracking\".';
$_MODULE['<{twenga}prestashop>twenga_5ac315e486b693637a06f490f308dc67'] = 'Etape 2 : Retournez ici et coller cette clé dans le champ « hash key ». Cliquez sur sauvegarder et activer.';
$_MODULE['<{twenga}prestashop>twenga_f5cff2635ec9ecf0249d33a7656f61c5'] = 'Vous n\'êtes pas inscrit à Twenga Ready to Sell ?';
$_MODULE['<{twenga}prestashop>twenga_f9c31cabc1e6928068e7394f5453e759'] = 'Comment tester Twenga et bénéficier des 500 premiers clics offerts';
$_MODULE['<{twenga}prestashop>twenga_87645feb1c92efecd6a6946d1b498fd7'] = 'Etape 1 : Cliquez sur ce lien pour vous inscrire à Twenga Ready To Sell';
$_MODULE['<{twenga}prestashop>twenga_b26917587d98330d93f87808fc9d7267'] = 's\'inscrire';
$_MODULE['<{twenga}prestashop>twenga_1d79f46fad241d4984e47165ca578ee9'] = '(des erreurs sont survenues : merci de contacter Twenga)';
$_MODULE['<{twenga}prestashop>twenga_195b3777fa9dcc91d27b86391e7f9a49'] = 'Etape 2 : Compléter le formulaire d\'inscription Twenga';
$_MODULE['<{twenga}prestashop>twenga_767a31e960aa760c42722d2e7373b2ad'] = 'Etape 3 : Une fois votre clé Twenga reçue, retournez ici et coller cette clé dans le champs „hash key“. Cliquez pour sauvegarder et activer.';
$_MODULE['<{twenga}prestashop>twenga_bc88fe7063d7e7da0bf08003f21a1ad2'] = 'Augmentez votre traffic - 500 clics offerts';
$_MODULE['<{twenga}prestashop>twenga_2d82e5a3931e70d2c94b9ba6e674edbc'] = 'Votre catalogue sera référencé sous une dizaine de jours. Une fois les 500 clics consommés, vous serez facturés au clic par catégorie de 0.05€ à 0.15€. Vous aurez accès à une interface de gestion complète et pouvez partir à tout moment.';
$_MODULE['<{twenga}prestashop>twenga_f9372612b4e86b53c45d31d7ca3402bb'] = 'Tarifs de Twenga';
$_MODULE['<{twenga}prestashop>twenga_1b972277504e523b2354830a1cbbf34b'] = 'Installation du suivi des ventes';
$_MODULE['<{twenga}prestashop>twenga_1b8d7e57253e5bdb39a7f8a8e4604a87'] = 'Renseignez ici la clé/hashkey Twenga et votre login/pass Twenga Ready to Sell';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Flux Rss';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'Hashkey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{twenga}prestashop>twenga_dcc247ef0aa275168664ec484511ccef'] = 'En cas d\'oubli de votre login, récupérez le ici';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{twenga}prestashop>twenga_aacdaeaf96cf431c6364b4dfe314b35c'] = 'Informations qui pré-rempliront le formulaire d\'inscription Twenga';
$_MODULE['<{twenga}prestashop>twenga_e4448edd2a6725ad3b1b7ca31eac1ff0'] = 'Les informations suivantes seront pré remplies dans lors de votre inscription à Twenga Ready to Sell. Merci de vérifier si les informations sont correctes.';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'l\'url du site';
$_MODULE['<{twenga}prestashop>twenga_49c0292b84058df9d4ee623efbd680d4'] = 'Flux Rss, la liste des produits en xml.';
$_MODULE['<{twenga}prestashop>twenga_9217c70a13a5a37fdef90ed92d18ca1b'] = 'Valeur automatiquement remplie, ne la changer pas.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'Le pays de la société E-commerce. Utilisez le code ISO_3166-1 Alpha-2 pour le format de pays ';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'Nom du site';
$_MODULE['<{twenga}prestashop>twenga_77587239bf4c54ea493c7033e1dbf636'] = 'Nom de famille';
$_MODULE['<{twenga}prestashop>twenga_bc910f8bdf70f29374f496f05be0330c'] = 'Prénom';
$_MODULE['<{twenga}prestashop>twenga_1e884e3078d9978e216a027ecd57fb34'] = 'E-mail';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Téléphone';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nom de l\'organisation';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Infos juridiques';
$_MODULE['<{twenga}prestashop>twenga_fc0d317121f61eeb44ede30a6648b9be'] = 'Infos juridiques de la société.';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Adresse';
$_MODULE['<{twenga}prestashop>twenga_8116ea5ccd73f945bb5e260861b0b570'] = 'Code postale';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Ville';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Annuler le tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Pour annuler le tracking, cliquez sur le lien suivant :';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Activer le tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Pour activer le tracking, cliquez sur le lien suivant :';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Activer';
$_MODULE['<{twenga}prestashop>twenga_09d0c75c525a2cb0bf2310e447ea8a45'] = 'La clé de hachage doit être définie pour utiliser Twenga API.';
$_MODULE['<{twenga}prestashop>twenga_12a4f08255155a828e10c2c513595fe1'] = 'Certains paramètres sont manquants ou le site n\'existe pas';
$_MODULE['<{twenga}prestashop>twengaobj_2823b98d043387f608f16d5830d63f5f'] = 'Pour activer le module Twenga, la constante \"PARTNER_AUTH_KEY\" doit être définit. L\'installation par défault de Prestashop contient cette valeur.';
$_MODULE['<{twenga}prestashop>twengaobj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'L\'object pour valider les champs doit être une instance de la classe TwengaFields';
$_MODULE['<{twenga}prestashop>twengaobj_b78d4ca3fa82bab9e21c8110511ed947'] = 'Le retour XML de la réponse HTTP n\'est pas analysable :';
$_MODULE['<{twenga}prestashop>twengaobj_7edc522b57a063ef075b68fdb791af40'] = 'la réponse HTTP est vide';
$_MODULE['<{twenga}prestashop>twengaobj_d00d3f61833c8686be3f0ca7df670e20'] = 'Cet appel aux Services Web Twenga à échoué et à retourné un statut HTTP de %d. Ce qui veut dire :';
$_MODULE['<{twenga}prestashop>twengaobj_5177c3a8e526ccb227441827d43d9583'] = 'La fonction que vous appelez n\'existe pas';
$_MODULE['<{twenga}prestashop>twengaobj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un champ requis est vide.';
$_MODULE['<{twenga}prestashop>twengaobj_f97fd38d65fe891d07fc1a157b0752a2'] = 'Le type du paramètre qui est envoyé est différent du type attendu.';
$_MODULE['<{twenga}prestashop>twengaobj_737b702af5cbf3c4b0e7404592bae85e'] = 'Le hash key n\'est pas valide';
$_MODULE['<{twenga}prestashop>twengaobj_c54550e963195bd4e80b862f40b8d574'] = 'Le hash key est requis';
$_MODULE['<{twenga}prestashop>twengaobj_c4e170c475b0285f284ccb066bcd81f4'] = 'Aucune commandes trouvées. Regardez les parmètres que vous transmettez';
$_MODULE['<{twenga}prestashop>twengaobj_54441256ce04ab07a29463646d0a9931'] = 'Une authentification est requise.';
$_MODULE['<{twenga}prestashop>twengaobj_802b207b05fe5cea22e11b9db804b33d'] = 'L\'authentification a échoué.';
$_MODULE['<{twenga}prestashop>twengaobj_629a8cfa226f98886062bfdc9666e266'] = 'L\'url n\'est pas valide.';
$_MODULE['<{twenga}prestashop>twengaobj_9fb66ea632c1aff220b180918df3c77c'] = 'Le serveur à rencontrer une \"internal server error\".';
$_MODULE['<{twenga}prestashop>twengaobj_6e182f2ba494a6720ce552ed2a255403'] = 'Le serveur n\'est pas accessible pour le moment';
$_MODULE['<{twenga}prestashop>twengaobj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'Cet appel aux Services Web Twenga a retourné un statut HTTP inattendu :';
$_MODULE['<{twenga}prestashop>twengaobj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Erreur n°';

==> prestashop_1.4.2.5.zip: prestashop/modules/twenga/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{twenga}prestashop>twenga_400b0c914f01bcecf50b936e652695b2'] = 'l\'API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_64ef67f03ba236aef261078101017d57'] = 'Rôle du module : export de vos produits sur Twenga et installation du suivi des ventes apportées par Twenga (inscription sur Twenga requise)';
$_MODULE['<{twenga}prestashop>twenga_2034864b8a4fce12f3621b7ec8912e95'] = 'Le module Twenga marche seulement dans certains pays (liste des iso codes :';
$_MODULE['<{twenga}prestashop>twenga_bcfaccebf745acfd5e75351095a5394a'] = 'Désactiver';
$_MODULE['<{twenga}prestashop>twenga_526d688f37a86d3c3f27d0c5016eb71d'] = 'Réinitialiser';
$_MODULE['<{twenga}prestashop>twenga_a27dfe771799a09fd55fea73286eb6ab'] = 'Désinstaller';
$_MODULE['<{twenga}prestashop>twenga_f2a6c498fb90ee345d997f888fce3b18'] = 'Supprimer';
$_MODULE['<{twenga}prestashop>twenga_bf4510198726bc0736e7705e10fffd8b'] = 'Si vous êtes inscrit sur Twenga, l’activation de ce module est obligatoire.';
$_MODULE['<{twenga}prestashop>twenga_9d156e107098a77332f309c765b72b9c'] = 'En cas de dysfonctionnement, désinstallez ce module, installez la version la plus récente ici puis renseignez à nouveau votre hashkey et login Twenga.';
$_MODULE['<{twenga}prestashop>twenga_a9d7299384e1f3fc346790328ffa8ac3'] = 'Pour vous désinscrire ou toute autre question, contactez Twenga sur votre compte.';
$_MODULE['<{twenga}prestashop>twenga_fb3ecfb2800400fb01b0bfd39903e9fb'] = 'Version plus récente';
$_MODULE['<{twenga}prestashop>twenga_ea4788705e6873b424c65e91c2846b19'] = 'Annuler';
$_MODULE['<{twenga}prestashop>twenga_69e591b18e717d483dbaa8e3ce89ce59'] = 'Les paramètres ne sont pas autorisés (voir détails) :';
$_MODULE['<{twenga}prestashop>twenga_75a462904fadc0cc16d084efaef4a9d0'] = 'Une erreur s\'est produite avec une méthode de l\'API Twenga (voir détails) :';
$_MODULE['<{twenga}prestashop>twenga_7edef656ee9e8861e734336a7adba650'] = 'Votre \"hashkey\" n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_3e6f1d35bdb6d0721c83c0a3f48ae345'] = 'Votre nom d\'utilisateur n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_19183e4de8ddfa3e032c112ba45fdc13'] = 'Votre mot de passe n\'est pas valide. Veuillez vérifier l\'email envoyé par Twenga.';
$_MODULE['<{twenga}prestashop>twenga_802b207b05fe5cea22e11b9db804b33d'] = 'Votre authentification à échoué.';
$_MODULE['<{twenga}prestashop>twenga_6702ebde453c9145652c0b007489904c'] = 'Veuillez vérifier l\'email envoyé par Twenga après souscription. Si une erreur persiste, contactez le service de Twenga.';
$_MODULE['<{twenga}prestashop>twenga_ddedf0f7b923553ef46616375e521381'] = 'Une erreur est apparue en passant les paramètres à l\'API Twenga.';
$_MODULE['<{twenga}prestashop>twenga_94a3b708cddc22d83742fdbd0a8970d7'] = 'Votre pays par défaut est';
$_MODULE['<{twenga}prestashop>twenga_1f75825a8f4b083cbed0f95efc09abfd'] = 'Veuilez sélectionner un des pays disponibles approuvés par Twenga';
$_MODULE['<{twenga}prestashop>twenga_3ea33020a5535b0157de47e53e463633'] = 'Suivez ce lien pour changer le pays';
$_MODULE['<{twenga}prestashop>twenga_d235beb5b777136184f6b794a27892e9'] = 'Twenga ne peut pas fonctionner sur la One page checkout';
$_MODULE['<{twenga}prestashop>twenga_5d79ec5a879860ff8546580001fe80ee'] = 'Pour utiliser le webservice de Twenga, vous devez activer l\'extension \'curl\' de PHP';
$_MODULE['<{twenga}prestashop>twenga_5f77daeb6fc30c87e051e5b5d11b034c'] = 'Des erreurs sont apparues lors de l\'appel de la methode \"getSubscription\" avec L\'API de Twenga';
$_MODULE['<{twenga}prestashop>twenga_da8ac71ff9563d9a5dd0f8894c8bc0ac'] = 'Référencez vos produits sur Twenga et suivez les ventes générées par Twenga';
$_MODULE['<{twenga}prestashop>twenga_0ed6e223384a822859461ca6bab72256'] = 'Vous êtes déjà inscrit à Twenga Ready to Sell ? ';
$_MODULE['<{twenga}prestashop>twenga_63f97ef2cb80a6cf0a8fa98453577601'] = 'Etape 1 : Récupérez votre clé Twenga dans l\'email envoyé par Twenga ou sur votre compte Twenga Ready to Sell (tools>tracking>hashkey). Cliquez aussi sur \"Tester le tracking\".';
$_MODULE['<{twenga}prestashop>twenga_5ac315e486b693637a06f490f308dc67'] = 'Etape 2 : Retournez ici et coller cette clé dans le champ « hash key ». Cliquez sur sauvegarder et activer.';
$_MODULE['<{twenga}prestashop>twenga_f5cff2635ec9ecf0249d33a7656f61c5'] = 'Vous n\'êtes pas inscrit à Twenga Ready to Sell ?';
$_MODULE['<{twenga}prestashop>twenga_f9c31cabc1e6928068e7394f5453e759'] = 'Comment tester Twenga et bénéficier des 500 premiers clics offerts';
$_MODULE['<{twenga}prestashop>twenga_87645feb1c92efecd6a6946d1b498fd7'] = 'Etape 1 : Cliquez sur ce lien pour vous inscrire à Twenga Ready To Sell';
$_MODULE['<{twenga}prestashop>twenga_b26917587d98330d93f87808fc9d7267'] = 's\'inscrire';
$_MODULE['<{twenga}prestashop>twenga_1d79f46fad241d4984e47165ca578ee9'] = '(des erreurs sont survenues : merci de contacter Twenga)';
$_MODULE['<{twenga}prestashop>twenga_195b3777fa9dcc91d27b86391e7f9a49'] = 'Etape 2 : Compléter le formulaire d\'inscription Twenga';
$_MODULE['<{twenga}prestashop>twenga_767a31e960aa760c42722d2e7373b2ad'] = 'Etape 3 : Une fois votre clé Twenga reçue, retournez ici et coller cette clé dans le champs „hash key“. Cliquez pour sauvegarder et activer.';
$_MODULE['<{twenga}prestashop>twenga_bc88fe7063d7e7da0bf08003f21a1ad2'] = 'Augmentez votre traffic - 500 clics offerts';
$_MODULE['<{twenga}prestashop>twenga_2d82e5a3931e70d2c94b9ba6e674edbc'] = 'Votre catalogue sera référencé sous une dizaine de jours. Une fois les 500 clics consommés, vous serez facturés au clic par catégorie de 0.05€ à 0.15€. Vous aurez accès à une interface de gestion complète et pouvez partir à tout moment.';
$_MODULE['<{twenga}prestashop>twenga_f9372612b4e86b53c45d31d7ca3402bb'] = 'Tarifs de Twenga';
$_MODULE['<{twenga}prestashop>twenga_1b972277504e523b2354830a1cbbf34b'] = 'Installation du suivi des ventes';
$_MODULE['<{twenga}prestashop>twenga_1b8d7e57253e5bdb39a7f8a8e4604a87'] = 'Renseignez ici la clé/hashkey Twenga et votre login/pass Twenga Ready to Sell';
$_MODULE['<{twenga}prestashop>twenga_a66daa775d445ee7da1bb20667b7c8e6'] = 'Flux Rss';
$_MODULE['<{twenga}prestashop>twenga_21baf392bfae2dadba6813e9fb843141'] = 'Hashkey';
$_MODULE['<{twenga}prestashop>twenga_99dea78007133396a7b8ed70578ac6ae'] = 'Login';
$_MODULE['<{twenga}prestashop>twenga_dc647eb65e6711e155375218212b3964'] = 'Mot de passe';
$_MODULE['<{twenga}prestashop>twenga_dcc247ef0aa275168664ec484511ccef'] = 'En cas d\'oubli de votre login, récupérez le ici';
$_MODULE['<{twenga}prestashop>twenga_c9cc8cce247e49bae79f15173ce97354'] = 'Sauvegarder';
$_MODULE['<{twenga}prestashop>twenga_aacdaeaf96cf431c6364b4dfe314b35c'] = 'Informations qui pré-rempliront le formulaire d\'inscription Twenga';
$_MODULE['<{twenga}prestashop>twenga_e4448edd2a6725ad3b1b7ca31eac1ff0'] = 'Les informations suivantes seront pré remplies dans lors de votre inscription à Twenga Ready to Sell. Merci de vérifier si les informations sont correctes.';
$_MODULE['<{twenga}prestashop>twenga_87fa3060dcb794dee724d4cb59b13cd6'] = 'l\'url du site';
$_MODULE['<{twenga}prestashop>twenga_49c0292b84058df9d4ee623efbd680d4'] = 'Flux Rss, la liste des produits en xml.';
$_MODULE['<{twenga}prestashop>twenga_9217c70a13a5a37fdef90ed92d18ca1b'] = 'Valeur automatiquement remplie, ne la changer pas.';
$_MODULE['<{twenga}prestashop>twenga_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{twenga}prestashop>twenga_95f01a5bae7b4b64a76372538e4fd315'] = 'Le pays de la société E-commerce. Utilisez le code ISO_3166-1 Alpha-2 pour le format de pays ';
$_MODULE['<{twenga}prestashop>twenga_734b599bad38d4210614bc176c53fefe'] = 'Nom du site';
$_MODULE['<{twenga}prestashop>twenga_77587239bf4c54ea493c7033e1dbf636'] = 'Nom de famille';
$_MODULE['<{twenga}prestashop>twenga_bc910f8bdf70f29374f496f05be0330c'] = 'Prénom';
$_MODULE['<{twenga}prestashop>twenga_1e884e3078d9978e216a027ecd57fb34'] = 'E-mail';
$_MODULE['<{twenga}prestashop>twenga_bcc254b55c4a1babdf1dcb82c207506b'] = 'Téléphone';
$_MODULE['<{twenga}prestashop>twenga_28bea34e08fa23a7d394c93bad717733'] = 'Nom de l\'organisation';
$_MODULE['<{twenga}prestashop>twenga_4ff5049a0938728934387c4d9cf38f94'] = 'Infos juridiques';
$_MODULE['<{twenga}prestashop>twenga_fc0d317121f61eeb44ede30a6648b9be'] = 'Infos juridiques de la société.';
$_MODULE['<{twenga}prestashop>twenga_dd7bf230fde8d4836917806aff6a6b27'] = 'Adresse';
$_MODULE['<{twenga}prestashop>twenga_8116ea5ccd73f945bb5e260861b0b570'] = 'Code postale';
$_MODULE['<{twenga}prestashop>twenga_57d056ed0984166336b7879c2af3657f'] = 'Ville';
$_MODULE['<{twenga}prestashop>twenga_fcb0c2a30548efc7048ea4bdfa4eba05'] = 'Annuler le tracking';
$_MODULE['<{twenga}prestashop>twenga_08473b95892d1cb8265ff2716cb81d54'] = 'Pour annuler le tracking, cliquez sur le lien suivant :';
$_MODULE['<{twenga}prestashop>twenga_2938a03ab100963b7349d83257fa9333'] = 'Activer le tracking';
$_MODULE['<{twenga}prestashop>twenga_cd07439a0c70b97a595de73218094a36'] = 'Pour activer le tracking, cliquez sur le lien suivant :';
$_MODULE['<{twenga}prestashop>twenga_a13367a8e2a3f3bf4f3409079e3fdf87'] = 'Activer';
$_MODULE['<{twenga}prestashop>twenga_09d0c75c525a2cb0bf2310e447ea8a45'] = 'La clé de hachage doit être définie pour utiliser Twenga API.';
$_MODULE['<{twenga}prestashop>twenga_12a4f08255155a828e10c2c513595fe1'] = 'Certains paramètres sont manquants ou le site n\'existe pas';
$_MODULE['<{twenga}prestashop>twengaobj_2823b98d043387f608f16d5830d63f5f'] = 'Pour activer le module Twenga, la constante \"PARTNER_AUTH_KEY\" doit être définit. L\'installation par défault de Prestashop contient cette valeur.';
$_MODULE['<{twenga}prestashop>twengaobj_9f7cd403f4ab77ce8c00426d4a01345e'] = 'L\'object pour valider les champs doit être une instance de la classe TwengaFields';
$_MODULE['<{twenga}prestashop>twengaobj_b78d4ca3fa82bab9e21c8110511ed947'] = 'Le retour XML de la réponse HTTP n\'est pas analysable :';
$_MODULE['<{twenga}prestashop>twengaobj_7edc522b57a063ef075b68fdb791af40'] = 'la réponse HTTP est vide';
$_MODULE['<{twenga}prestashop>twengaobj_d00d3f61833c8686be3f0ca7df670e20'] = 'Cet appel aux Services Web Twenga à échoué et à retourné un statut HTTP de %d. Ce qui veut dire :';
$_MODULE['<{twenga}prestashop>twengaobj_5177c3a8e526ccb227441827d43d9583'] = 'La fonction que vous appelez n\'existe pas';
$_MODULE['<{twenga}prestashop>twengaobj_3718cdfdc7439f35aed9f053b5991baf'] = 'Un champ requis est vide.';
$_MODULE['<{twenga}prestashop>twengaobj_f97fd38d65fe891d07fc1a157b0752a2'] = 'Le type du paramètre qui est envoyé est différent du type attendu.';
$_MODULE['<{twenga}prestashop>twengaobj_737b702af5cbf3c4b0e7404592bae85e'] = 'Le hash key n\'est pas valide';
$_MODULE['<{twenga}prestashop>twengaobj_c54550e963195bd4e80b862f40b8d574'] = 'Le hash key est requis';
$_MODULE['<{twenga}prestashop>twengaobj_c4e170c475b0285f284ccb066bcd81f4'] = 'Aucune commandes trouvées. Regardez les parmètres que vous transmettez';
$_MODULE['<{twenga}prestashop>twengaobj_54441256ce04ab07a29463646d0a9931'] = 'Une authentification est requise.';
$_MODULE['<{twenga}prestashop>twengaobj_802b207b05fe5cea22e11b9db804b33d'] = 'L\'authentification a échoué.';
$_MODULE['<{twenga}prestashop>twengaobj_629a8cfa226f98886062bfdc9666e266'] = 'L\'url n\'est pas valide.';
$_MODULE['<{twenga}prestashop>twengaobj_9fb66ea632c1aff220b180918df3c77c'] = 'Le serveur à rencontrer une \"internal server error\".';
$_MODULE['<{twenga}prestashop>twengaobj_6e182f2ba494a6720ce552ed2a255403'] = 'Le serveur n\'est pas accessible pour le moment';
$_MODULE['<{twenga}prestashop>twengaobj_4252fb7eb531ed1ec250e5c16f8ced37'] = 'Cet appel aux Services Web Twenga a retourné un statut HTTP inattendu :';
$_MODULE['<{twenga}prestashop>twengaobj_5619f08f21127bd8f72ec9bbb25031ac'] = 'Erreur n°';
